==> scanbot_sdk-2.0.0.tar.gz: ios/Classes/Extensions/SDK/Machine Codes/SBSDKBarcodeScannerResult.swift <==
//
//  SBSDKBarcodeScannerResult.swift
//  scanbot_sdk
//
//  Created by Yevgeniy Knizhnik on 04.05.20.
//

import Foundation
import ScanbotSDK

extension SBSDKBarcodeScannerResult {
    var encodedDictionary: [String: Any?] {

        let imageURL = PluginPreferences.shared.newStorageCustomFileURL(extensionString: "jpeg")
        var imageURLString: String? = imageURL.absoluteString
        do {
            try UIImageJPEGRepresentation(barcodeImage, 0.9)?.write(to: imageURL)
        } catch {
            imageURLString = nil
        }

        var dictionary: [String: Any?] = ["text": self.rawTextString,
                                          "barcodeFormat": self.type.encodedString,
                                          "barcodeImageUri": imageURLString]

        if let parsedResult = self.parsedFormattedResult {
            var updatedResult = parsedResult
            updatedResult["parsedSuccessful"] = self.formattedResult.parsedSuccessful
            dictionary["formattedResult"] = updatedResult
        }

        return dictionary
    }

    private var parsedFormattedResult: [String:Any?]? {
        if let formattedResult = self.formattedResult as? SBSDKVCardDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKAAMVADocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKIDCardPDF417DocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKSEPADocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKDisabilityCertificateDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKBoardingPassDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKMedicalPlanDocumentFormat {
            return formattedResult.encodedDictionary
        }

        return nil
    }
}

==> scanbot_sdk-2.0.1.tar.gz: ios/Classes/Extensions/SDK/Machine Codes/SBSDKBarcodeScannerResult.swift <==
//
//  SBSDKBarcodeScannerResult.swift
//  scanbot_sdk
//
//  Created by Yevgeniy Knizhnik on 04.05.20.
//

import Foundation
import ScanbotSDK

extension SBSDKBarcodeScannerResult {
    var encodedDictionary: [String: Any?] {

        let imageURL = PluginPreferences.shared.newStorageCustomFileURL(extensionString: "jpeg")
        var imageURLString: String? = imageURL.absoluteString
        do {
            try barcodeImage.jpegData(compressionQuality: 0.9)?.write(to: imageURL)
        } catch {
            imageURLString = nil
        }

        var dictionary: [String: Any?] = ["text": self.rawTextString,
                                          "barcodeFormat": self.type.encodedString,
                                          "barcodeImageUri": imageURLString]

        if let parsedResult = self.parsedFormattedResult {
            var updatedResult = parsedResult
            updatedResult["parsedSuccessful"] = self.formattedResult.parsedSuccessful
            dictionary["formattedResult"] = updatedResult
        }

        return dictionary
    }

    private var parsedFormattedResult: [String:Any?]? {
        if let formattedResult = self.formattedResult as? SBSDKVCardDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKAAMVADocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKIDCardPDF417DocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKSEPADocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKDisabilityCertificateDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKBoardingPassDocumentFormat {
            return formattedResult.encodedDictionary
        } else if let formattedResult = self.formattedResult as? SBSDKMedicalPlanDocumentFormat {
            return formattedResult.encodedDictionary
        }

        return nil
    }
}
